/*  *******************************************************************************************
 *  ATTENTION!
 *  THIS IS A GENERATED FILE FROM https://github.com/salesforce/lds-lightning-platform
 *  If you would like to contribute to LDS, please follow the steps outlined in the git repo.
 *  Any changes made to this file in p4 will be automatically overwritten.
 *  *******************************************************************************************
 */
/* proxy-compat-disable */
import { createWireAdapterConstructor } from 'force/ldsBindings';

const { hasOwnProperty: ObjectPrototypeHasOwnProperty } = Object.prototype;
const { keys: ObjectKeys, freeze: ObjectFreeze } = Object;
const { isArray: ArrayIsArray } = Array;
/**
 * Validates an adapter config is well-formed.
 * @param config The config to validate.
 * @param adapter The adapter validation configuration.
 * @param oneOf The keys the config must contain at least one of.
 * @throws A TypeError if config doesn't satisfy the adapter's config validation.
 */
function validateConfig(config, adapter, oneOf) {
    const { displayName } = adapter;
    const { required, optional, unsupported } = adapter.parameters;
    if (config === undefined ||
        required.every(req => ObjectPrototypeHasOwnProperty.call(config, req)) === false) {
        throw new TypeError(`adapter ${displayName} configuration must specify ${required.sort().join(', ')}`);
    }
    if (oneOf && oneOf.some(req => ObjectPrototypeHasOwnProperty.call(config, req)) === false) {
        throw new TypeError(`adapter ${displayName} configuration must specify one of ${oneOf.sort().join(', ')}`);
    }
    if (unsupported !== undefined &&
        unsupported.some(req => ObjectPrototypeHasOwnProperty.call(config, req))) {
        throw new TypeError(`adapter ${displayName} does not yet support ${unsupported.sort().join(', ')}`);
    }
    const supported = required.concat(optional);
    if (ObjectKeys(config).some(key => !supported.includes(key))) {
        throw new TypeError(`adapter ${displayName} configuration supports only ${supported.sort().join(', ')}`);
    }
}
function untrustedIsObject(untrusted) {
    return typeof untrusted === 'object' && untrusted !== null && ArrayIsArray(untrusted) === false;
}
function areRequiredParametersPresent(config, configPropertyNames) {
    return configPropertyNames.parameters.required.every(req => req in config);
}
const SNAPSHOT_STATE_UNFULFILLED = 'Unfulfilled';
const snapshotRefreshOptions = {
    headers: {
        'Cache-Control': 'no-cache',
    },
};
const keyPrefix = 'Commerce::';

const { freeze: ObjectFreeze$1, keys: ObjectKeys$1 } = Object;
const { isArray: ArrayIsArray$1 } = Array;
const { stringify: JSONStrinify } = JSON;
function createLink(ref) {
    return {
        __ref: ref,
    };
}

function validate(obj, path = 'ProductCategoryRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray$1(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_description = obj.description;
        const path_description = path + '.description';
        let obj_description_union0 = null;
        const obj_description_union0_error = (() => {
            if (typeof obj_description !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_description + '" (at "' + path_description + '")');
            }
        })();
        if (obj_description_union0_error != null) {
            obj_description_union0 = obj_description_union0_error.message;
        }
        let obj_description_union1 = null;
        const obj_description_union1_error = (() => {
            if (obj_description !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_description + '" (at "' + path_description + '")');
            }
        })();
        if (obj_description_union1_error != null) {
            obj_description_union1 = obj_description_union1_error.message;
        }
        if (obj_description_union0 && obj_description_union1) {
            let message = 'Object doesn\'t match union (at "' + path_description + '")';
            message += '\n' + obj_description_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_description_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_id = obj.id;
        const path_id = path + '.id';
        let obj_id_union0 = null;
        const obj_id_union0_error = (() => {
            if (typeof obj_id !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_id + '" (at "' + path_id + '")');
            }
        })();
        if (obj_id_union0_error != null) {
            obj_id_union0 = obj_id_union0_error.message;
        }
        let obj_id_union1 = null;
        const obj_id_union1_error = (() => {
            if (obj_id !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_id + '" (at "' + path_id + '")');
            }
        })();
        if (obj_id_union1_error != null) {
            obj_id_union1 = obj_id_union1_error.message;
        }
        if (obj_id_union0 && obj_id_union1) {
            let message = 'Object doesn\'t match union (at "' + path_id + '")';
            message += '\n' + obj_id_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_id_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_name = obj.name;
        const path_name = path + '.name';
        if (typeof obj_name !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_name + '" (at "' + path_name + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}
function deepFreeze(input) {
    ObjectFreeze$1(input);
}

function validate$1(obj, path = 'ProductCategoryPathRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray$1(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_path = obj.path;
        const path_path = path + '.path';
        if (!ArrayIsArray$1(obj_path)) {
            return new TypeError('Expected "array" but received "' + typeof obj_path + '" (at "' + path_path + '")');
        }
        for (let i = 0; i < obj_path.length; i++) {
            const obj_path_item = obj_path[i];
            const path_path_item = path_path + '[' + i + ']';
            const referenceProductCategoryRepresentationValidationError = validate(obj_path_item, path_path_item);
            if (referenceProductCategoryRepresentationValidationError !== null) {
                let message = 'Object doesn\'t match ProductCategoryRepresentation (at "' + path_path_item + '")\n';
                message += referenceProductCategoryRepresentationValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
                return new TypeError(message);
            }
        }
    })();
    return v_error === undefined ? null : v_error;
}
function normalize(input, existing, path, lds, store, timestamp) {
    return input;
}
const select = function ProductCategoryPathRepresentationSelect() {
    return {
        kind: 'Fragment',
        private: [],
        opaque: true
    };
};
function equals(existing, incoming) {
    if (JSONStrinify(incoming) !== JSONStrinify(existing)) {
        return false;
    }
    return true;
}
function deepFreeze$1(input) {
    const input_path = input.path;
    for (let i = 0; i < input_path.length; i++) {
        const input_path_item = input_path[i];
        deepFreeze(input_path_item);
    }
    ObjectFreeze$1(input_path);
    ObjectFreeze$1(input);
}
const ingest = function ProductCategoryPathRepresentationIngest(input, path, lds, store, timestamp) {
    if (process.env.NODE_ENV !== 'production') {
        const validateError = validate$1(input);
        if (validateError !== null) {
            throw validateError;
        }
    }
    const key = path.fullPath;
    let incomingRecord = normalize(input, store.records[key], {
        fullPath: key,
        parent: path.parent
    });
    const existingRecord = store.records[key];
    deepFreeze$1(input);
    if (existingRecord === undefined || equals(existingRecord, incomingRecord) === false) {
        lds.storePublish(key, incomingRecord);
    }
    return createLink(key);
};

function select$1(lds, params) {
    return select();
}
function keyBuilder(params) {
    return keyPrefix + 'ProductCategoryPathRepresentation(' + 'productCategoryId:' + params.urlParams.productCategoryId + ',' + 'webstoreId:' + params.urlParams.webstoreId + ')';
}
function ingestSuccess(lds, resourceParams, request, response, snapshotRefresh) {
    const { body } = response;
    const key = keyBuilder(resourceParams);
    lds.storeIngest(key, request, body);
    const snapshot = lds.storeLookup({
        recordId: key,
        node: select$1(),
        variables: {},
    }, snapshotRefresh);
    if (process.env.NODE_ENV !== 'production') {
        if (response.headers !== undefined && snapshot.state !== 'Fulfilled') {
            throw new Error('Invalid network response. Expected resource response to result in Fulfilled snapshot');
        }
        if (!(snapshot.state === 'Fulfilled' || snapshot.state === 'Stale')) {
            throw new Error('Invalid resource response. Expected resource response to result in Fulfilled or Stale snapshot');
        }
    }
    return snapshot;
}
function ingestError(lds, params, error, snapshotRefresh) {
    const key = keyBuilder(params);
    lds.storeIngestFetchResponse(key, error);
    return lds.errorSnapshot(error, snapshotRefresh);
}
function createResourceRequest(config) {
    const headers = {};
    return {
        baseUri: '/services/data/v50.0',
        basePath: '/commerce/webstores/' + config.urlParams.webstoreId + '/product-category-path/product-categories/' + config.urlParams.productCategoryId + '',
        method: 'get',
        body: null,
        urlParams: config.urlParams,
        queryParams: {},
        ingest: ingest,
        headers,
    };
}

const adapterName = 'getProductCategoryPath';
const getProductCategoryPath_ConfigPropertyNames = {
    displayName: 'getProductCategoryPath',
    parameters: {
        required: ['productCategoryId', 'webstoreId'],
        optional: []
    }
};
function createResourceParams(config) {
    return {
        urlParams: {
            productCategoryId: config.productCategoryId, webstoreId: config.webstoreId
        }
    };
}
function typeCheckConfig(untrustedConfig) {
    const config = {};
    const untrustedConfig_productCategoryId = untrustedConfig.productCategoryId;
    if (typeof untrustedConfig_productCategoryId === 'string') {
        config.productCategoryId = untrustedConfig_productCategoryId;
    }
    const untrustedConfig_webstoreId = untrustedConfig.webstoreId;
    if (typeof untrustedConfig_webstoreId === 'string') {
        config.webstoreId = untrustedConfig_webstoreId;
    }
    return config;
}
function validateAdapterConfig(untrustedConfig, configPropertyNames) {
    if (!untrustedIsObject(untrustedConfig)) {
        return null;
    }
    if (process.env.NODE_ENV !== 'production') {
        validateConfig(untrustedConfig, configPropertyNames);
    }
    const config = typeCheckConfig(untrustedConfig);
    if (!areRequiredParametersPresent(config, configPropertyNames)) {
        return null;
    }
    return config;
}
function buildInMemorySnapshot(lds, config) {
    const resourceParams = createResourceParams(config);
    const selector = {
        recordId: keyBuilder(resourceParams),
        node: select$1(),
        variables: {},
    };
    return lds.storeLookup(selector, {
        config,
        resolve: () => buildNetworkSnapshot(lds, config, snapshotRefreshOptions)
    });
}
function onResourceResponseSuccess(lds, config, resourceParams, request, response) {
    const snapshot = ingestSuccess(lds, resourceParams, request, response, {
        config,
        resolve: () => buildNetworkSnapshot(lds, config, snapshotRefreshOptions)
    });
    lds.storeBroadcast();
    return snapshot;
}
function onResourceResponseError(lds, config, resourceParams, response) {
    const snapshot = ingestError(lds, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot(lds, config, snapshotRefreshOptions)
    });
    lds.storeBroadcast();
    return snapshot;
}
function buildNetworkSnapshot(lds, config, override) {
    const resourceParams = createResourceParams(config);
    const request = createResourceRequest(resourceParams);
    return lds.dispatchResourceRequest(request, override)
        .then((response) => {
        return onResourceResponseSuccess(lds, config, resourceParams, request, response);
    }, (response) => {
        return onResourceResponseError(lds, config, resourceParams, response);
    });
}
function resolveUnfulfilledSnapshot(lds, config, snapshot) {
    const resourceParams = createResourceParams(config);
    const request = createResourceRequest(resourceParams);
    return lds.resolveUnfulfilledSnapshot(request, snapshot)
        .then((response) => {
        return onResourceResponseSuccess(lds, config, resourceParams, request, response);
    }, (response) => {
        return onResourceResponseError(lds, config, resourceParams, response);
    });
}
const getProductCategoryPathAdapterFactory = (lds) => function getProductCategoryPath(untrustedConfig) {
    const config = validateAdapterConfig(untrustedConfig, getProductCategoryPath_ConfigPropertyNames);
    // Invalid or incomplete config
    if (config === null) {
        return null;
    }
    const cacheSnapshot = buildInMemorySnapshot(lds, config);
    // Cache Hit
    if (lds.snapshotDataAvailable(cacheSnapshot) === true) {
        return cacheSnapshot;
    }
    if (cacheSnapshot.state === SNAPSHOT_STATE_UNFULFILLED) {
        return resolveUnfulfilledSnapshot(lds, config, cacheSnapshot);
    }
    return buildNetworkSnapshot(lds, config);
};

function validate$2(obj, path = 'ProductMediaRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray$1(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_alternateText = obj.alternateText;
        const path_alternateText = path + '.alternateText';
        let obj_alternateText_union0 = null;
        const obj_alternateText_union0_error = (() => {
            if (typeof obj_alternateText !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_alternateText + '" (at "' + path_alternateText + '")');
            }
        })();
        if (obj_alternateText_union0_error != null) {
            obj_alternateText_union0 = obj_alternateText_union0_error.message;
        }
        let obj_alternateText_union1 = null;
        const obj_alternateText_union1_error = (() => {
            if (obj_alternateText !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_alternateText + '" (at "' + path_alternateText + '")');
            }
        })();
        if (obj_alternateText_union1_error != null) {
            obj_alternateText_union1 = obj_alternateText_union1_error.message;
        }
        if (obj_alternateText_union0 && obj_alternateText_union1) {
            let message = 'Object doesn\'t match union (at "' + path_alternateText + '")';
            message += '\n' + obj_alternateText_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_alternateText_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_contentVersionId = obj.contentVersionId;
        const path_contentVersionId = path + '.contentVersionId';
        let obj_contentVersionId_union0 = null;
        const obj_contentVersionId_union0_error = (() => {
            if (typeof obj_contentVersionId !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_contentVersionId + '" (at "' + path_contentVersionId + '")');
            }
        })();
        if (obj_contentVersionId_union0_error != null) {
            obj_contentVersionId_union0 = obj_contentVersionId_union0_error.message;
        }
        let obj_contentVersionId_union1 = null;
        const obj_contentVersionId_union1_error = (() => {
            if (obj_contentVersionId !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_contentVersionId + '" (at "' + path_contentVersionId + '")');
            }
        })();
        if (obj_contentVersionId_union1_error != null) {
            obj_contentVersionId_union1 = obj_contentVersionId_union1_error.message;
        }
        if (obj_contentVersionId_union0 && obj_contentVersionId_union1) {
            let message = 'Object doesn\'t match union (at "' + path_contentVersionId + '")';
            message += '\n' + obj_contentVersionId_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_contentVersionId_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_id = obj.id;
        const path_id = path + '.id';
        let obj_id_union0 = null;
        const obj_id_union0_error = (() => {
            if (typeof obj_id !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_id + '" (at "' + path_id + '")');
            }
        })();
        if (obj_id_union0_error != null) {
            obj_id_union0 = obj_id_union0_error.message;
        }
        let obj_id_union1 = null;
        const obj_id_union1_error = (() => {
            if (obj_id !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_id + '" (at "' + path_id + '")');
            }
        })();
        if (obj_id_union1_error != null) {
            obj_id_union1 = obj_id_union1_error.message;
        }
        if (obj_id_union0 && obj_id_union1) {
            let message = 'Object doesn\'t match union (at "' + path_id + '")';
            message += '\n' + obj_id_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_id_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_mediaType = obj.mediaType;
        const path_mediaType = path + '.mediaType';
        if (typeof obj_mediaType !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_mediaType + '" (at "' + path_mediaType + '")');
        }
        const obj_sortOrder = obj.sortOrder;
        const path_sortOrder = path + '.sortOrder';
        if (typeof obj_sortOrder !== 'number' || (typeof obj_sortOrder === 'number' && Math.floor(obj_sortOrder) !== obj_sortOrder)) {
            return new TypeError('Expected "integer" but received "' + typeof obj_sortOrder + '" (at "' + path_sortOrder + '")');
        }
        const obj_title = obj.title;
        const path_title = path + '.title';
        if (typeof obj_title !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_title + '" (at "' + path_title + '")');
        }
        const obj_url = obj.url;
        const path_url = path + '.url';
        if (typeof obj_url !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_url + '" (at "' + path_url + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}
function deepFreeze$2(input) {
    ObjectFreeze$1(input);
}

function validate$3(obj, path = 'ProductEntitlementRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray$1(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_canViewPrice = obj.canViewPrice;
        const path_canViewPrice = path + '.canViewPrice';
        let obj_canViewPrice_union0 = null;
        const obj_canViewPrice_union0_error = (() => {
            if (typeof obj_canViewPrice !== 'boolean') {
                return new TypeError('Expected "boolean" but received "' + typeof obj_canViewPrice + '" (at "' + path_canViewPrice + '")');
            }
        })();
        if (obj_canViewPrice_union0_error != null) {
            obj_canViewPrice_union0 = obj_canViewPrice_union0_error.message;
        }
        let obj_canViewPrice_union1 = null;
        const obj_canViewPrice_union1_error = (() => {
            if (obj_canViewPrice !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_canViewPrice + '" (at "' + path_canViewPrice + '")');
            }
        })();
        if (obj_canViewPrice_union1_error != null) {
            obj_canViewPrice_union1 = obj_canViewPrice_union1_error.message;
        }
        if (obj_canViewPrice_union0 && obj_canViewPrice_union1) {
            let message = 'Object doesn\'t match union (at "' + path_canViewPrice + '")';
            message += '\n' + obj_canViewPrice_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_canViewPrice_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
    })();
    return v_error === undefined ? null : v_error;
}
function deepFreeze$3(input) {
    ObjectFreeze$1(input);
}

function validate$4(obj, path = 'ProductMediaGroupRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray$1(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_developerName = obj.developerName;
        const path_developerName = path + '.developerName';
        if (typeof obj_developerName !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_developerName + '" (at "' + path_developerName + '")');
        }
        const obj_id = obj.id;
        const path_id = path + '.id';
        if (typeof obj_id !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_id + '" (at "' + path_id + '")');
        }
        const obj_mediaItems = obj.mediaItems;
        const path_mediaItems = path + '.mediaItems';
        if (!ArrayIsArray$1(obj_mediaItems)) {
            return new TypeError('Expected "array" but received "' + typeof obj_mediaItems + '" (at "' + path_mediaItems + '")');
        }
        for (let i = 0; i < obj_mediaItems.length; i++) {
            const obj_mediaItems_item = obj_mediaItems[i];
            const path_mediaItems_item = path_mediaItems + '[' + i + ']';
            const referenceProductMediaRepresentationValidationError = validate$2(obj_mediaItems_item, path_mediaItems_item);
            if (referenceProductMediaRepresentationValidationError !== null) {
                let message = 'Object doesn\'t match ProductMediaRepresentation (at "' + path_mediaItems_item + '")\n';
                message += referenceProductMediaRepresentationValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
                return new TypeError(message);
            }
        }
        const obj_name = obj.name;
        const path_name = path + '.name';
        if (typeof obj_name !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_name + '" (at "' + path_name + '")');
        }
        const obj_usageType = obj.usageType;
        const path_usageType = path + '.usageType';
        if (typeof obj_usageType !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_usageType + '" (at "' + path_usageType + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}
function deepFreeze$4(input) {
    const input_mediaItems = input.mediaItems;
    for (let i = 0; i < input_mediaItems.length; i++) {
        const input_mediaItems_item = input_mediaItems[i];
        deepFreeze$2(input_mediaItems_item);
    }
    ObjectFreeze$1(input_mediaItems);
    ObjectFreeze$1(input);
}

function validate$5(obj, path = 'ProductDetailRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray$1(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_defaultImage = obj.defaultImage;
        const path_defaultImage = path + '.defaultImage';
        const referenceProductMediaRepresentationValidationError = validate$2(obj_defaultImage, path_defaultImage);
        if (referenceProductMediaRepresentationValidationError !== null) {
            let message = 'Object doesn\'t match ProductMediaRepresentation (at "' + path_defaultImage + '")\n';
            message += referenceProductMediaRepresentationValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_entitlement = obj.entitlement;
        const path_entitlement = path + '.entitlement';
        const referenceProductEntitlementRepresentationValidationError = validate$3(obj_entitlement, path_entitlement);
        if (referenceProductEntitlementRepresentationValidationError !== null) {
            let message = 'Object doesn\'t match ProductEntitlementRepresentation (at "' + path_entitlement + '")\n';
            message += referenceProductEntitlementRepresentationValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_fields = obj.fields;
        const path_fields = path + '.fields';
        if (typeof obj_fields !== 'object' || ArrayIsArray$1(obj_fields) || obj_fields === null) {
            return new TypeError('Expected "object" but received "' + typeof obj_fields + '" (at "' + path_fields + '")');
        }
        const obj_fields_keys = ObjectKeys$1(obj_fields);
        for (let i = 0; i < obj_fields_keys.length; i++) {
            const key = obj_fields_keys[i];
            const obj_fields_prop = obj_fields[key];
            const path_fields_prop = path_fields + '["' + key + '"]';
            let obj_fields_prop_union0 = null;
            const obj_fields_prop_union0_error = (() => {
                if (typeof obj_fields_prop !== 'string') {
                    return new TypeError('Expected "string" but received "' + typeof obj_fields_prop + '" (at "' + path_fields_prop + '")');
                }
            })();
            if (obj_fields_prop_union0_error != null) {
                obj_fields_prop_union0 = obj_fields_prop_union0_error.message;
            }
            let obj_fields_prop_union1 = null;
            const obj_fields_prop_union1_error = (() => {
                if (obj_fields_prop !== null) {
                    return new TypeError('Expected "null" but received "' + typeof obj_fields_prop + '" (at "' + path_fields_prop + '")');
                }
            })();
            if (obj_fields_prop_union1_error != null) {
                obj_fields_prop_union1 = obj_fields_prop_union1_error.message;
            }
            if (obj_fields_prop_union0 && obj_fields_prop_union1) {
                let message = 'Object doesn\'t match union (at "' + path_fields_prop + '")';
                message += '\n' + obj_fields_prop_union0.split('\n').map((line) => '\t' + line).join('\n');
                message += '\n' + obj_fields_prop_union1.split('\n').map((line) => '\t' + line).join('\n');
                return new TypeError(message);
            }
        }
        const obj_id = obj.id;
        const path_id = path + '.id';
        if (typeof obj_id !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_id + '" (at "' + path_id + '")');
        }
        const obj_mediaGroups = obj.mediaGroups;
        const path_mediaGroups = path + '.mediaGroups';
        if (!ArrayIsArray$1(obj_mediaGroups)) {
            return new TypeError('Expected "array" but received "' + typeof obj_mediaGroups + '" (at "' + path_mediaGroups + '")');
        }
        for (let i = 0; i < obj_mediaGroups.length; i++) {
            const obj_mediaGroups_item = obj_mediaGroups[i];
            const path_mediaGroups_item = path_mediaGroups + '[' + i + ']';
            const referenceProductMediaGroupRepresentationValidationError = validate$4(obj_mediaGroups_item, path_mediaGroups_item);
            if (referenceProductMediaGroupRepresentationValidationError !== null) {
                let message = 'Object doesn\'t match ProductMediaGroupRepresentation (at "' + path_mediaGroups_item + '")\n';
                message += referenceProductMediaGroupRepresentationValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
                return new TypeError(message);
            }
        }
        const obj_primaryProductCategoryPath = obj.primaryProductCategoryPath;
        const path_primaryProductCategoryPath = path + '.primaryProductCategoryPath';
        const referenceProductCategoryPathRepresentationValidationError = validate$1(obj_primaryProductCategoryPath, path_primaryProductCategoryPath);
        if (referenceProductCategoryPathRepresentationValidationError !== null) {
            let message = 'Object doesn\'t match ProductCategoryPathRepresentation (at "' + path_primaryProductCategoryPath + '")\n';
            message += referenceProductCategoryPathRepresentationValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
    })();
    return v_error === undefined ? null : v_error;
}
function normalize$1(input, existing, path, lds, store, timestamp) {
    return input;
}
const select$2 = function ProductDetailRepresentationSelect() {
    return {
        kind: 'Fragment',
        private: [],
        opaque: true
    };
};
function equals$1(existing, incoming) {
    if (JSONStrinify(incoming) !== JSONStrinify(existing)) {
        return false;
    }
    return true;
}
function deepFreeze$5(input) {
    const input_defaultImage = input.defaultImage;
    deepFreeze$2(input_defaultImage);
    const input_entitlement = input.entitlement;
    deepFreeze$3(input_entitlement);
    const input_fields = input.fields;
    const input_fields_keys = Object.keys(input_fields);
    const input_fields_length = input_fields_keys.length;
    for (let i = 0; i < input_fields_length; i++) {
        const key = input_fields_keys[i];
    }
    ObjectFreeze$1(input_fields);
    const input_mediaGroups = input.mediaGroups;
    for (let i = 0; i < input_mediaGroups.length; i++) {
        const input_mediaGroups_item = input_mediaGroups[i];
        deepFreeze$4(input_mediaGroups_item);
    }
    ObjectFreeze$1(input_mediaGroups);
    const input_primaryProductCategoryPath = input.primaryProductCategoryPath;
    deepFreeze$1(input_primaryProductCategoryPath);
    ObjectFreeze$1(input);
}
const ingest$1 = function ProductDetailRepresentationIngest(input, path, lds, store, timestamp) {
    if (process.env.NODE_ENV !== 'production') {
        const validateError = validate$5(input);
        if (validateError !== null) {
            throw validateError;
        }
    }
    const key = path.fullPath;
    let incomingRecord = normalize$1(input, store.records[key], {
        fullPath: key,
        parent: path.parent
    });
    const existingRecord = store.records[key];
    deepFreeze$5(input);
    if (existingRecord === undefined || equals$1(existingRecord, incomingRecord) === false) {
        lds.storePublish(key, incomingRecord);
    }
    return createLink(key);
};

function select$3(lds, params) {
    return select$2();
}
function keyBuilder$1(params) {
    return keyPrefix + 'ProductDetailRepresentation(' + 'effectiveAccountId:' + params.queryParams.effectiveAccountId + ',' + 'excludeEntitlement:' + params.queryParams.excludeEntitlement + ',' + 'excludeFields:' + params.queryParams.excludeFields + ',' + 'excludeMedia:' + params.queryParams.excludeMedia + ',' + 'excludePrimaryProductCategory:' + params.queryParams.excludePrimaryProductCategory + ',' + 'fields:' + params.queryParams.fields + ',' + 'mediaGroups:' + params.queryParams.mediaGroups + ',' + 'productId:' + params.urlParams.productId + ',' + 'webstoreId:' + params.urlParams.webstoreId + ')';
}
function ingestSuccess$1(lds, resourceParams, request, response, snapshotRefresh) {
    const { body } = response;
    const key = keyBuilder$1(resourceParams);
    lds.storeIngest(key, request, body);
    const snapshot = lds.storeLookup({
        recordId: key,
        node: select$3(),
        variables: {},
    }, snapshotRefresh);
    if (process.env.NODE_ENV !== 'production') {
        if (response.headers !== undefined && snapshot.state !== 'Fulfilled') {
            throw new Error('Invalid network response. Expected resource response to result in Fulfilled snapshot');
        }
        if (!(snapshot.state === 'Fulfilled' || snapshot.state === 'Stale')) {
            throw new Error('Invalid resource response. Expected resource response to result in Fulfilled or Stale snapshot');
        }
    }
    return snapshot;
}
function ingestError$1(lds, params, error, snapshotRefresh) {
    const key = keyBuilder$1(params);
    lds.storeIngestFetchResponse(key, error);
    return lds.errorSnapshot(error, snapshotRefresh);
}
function createResourceRequest$1(config) {
    const headers = {};
    return {
        baseUri: '/services/data/v50.0',
        basePath: '/commerce/webstores/' + config.urlParams.webstoreId + '/products/' + config.urlParams.productId + '',
        method: 'get',
        body: null,
        urlParams: config.urlParams,
        queryParams: config.queryParams,
        ingest: ingest$1,
        headers,
    };
}

const adapterName$1 = 'getProduct';
const getProduct_ConfigPropertyNames = {
    displayName: 'getProduct',
    parameters: {
        required: ['productId', 'webstoreId'],
        optional: ['effectiveAccountId', 'excludeEntitlement', 'excludeFields', 'excludeMedia', 'excludePrimaryProductCategory', 'fields', 'mediaGroups']
    }
};
function createResourceParams$1(config) {
    return {
        urlParams: {
            productId: config.productId, webstoreId: config.webstoreId
        },
        queryParams: {
            effectiveAccountId: config.effectiveAccountId, excludeEntitlement: config.excludeEntitlement, excludeFields: config.excludeFields, excludeMedia: config.excludeMedia, excludePrimaryProductCategory: config.excludePrimaryProductCategory, fields: config.fields, mediaGroups: config.mediaGroups
        }
    };
}
function typeCheckConfig$1(untrustedConfig) {
    const config = {};
    const untrustedConfig_productId = untrustedConfig.productId;
    if (typeof untrustedConfig_productId === 'string') {
        config.productId = untrustedConfig_productId;
    }
    const untrustedConfig_webstoreId = untrustedConfig.webstoreId;
    if (typeof untrustedConfig_webstoreId === 'string') {
        config.webstoreId = untrustedConfig_webstoreId;
    }
    const untrustedConfig_effectiveAccountId = untrustedConfig.effectiveAccountId;
    if (typeof untrustedConfig_effectiveAccountId === 'string') {
        config.effectiveAccountId = untrustedConfig_effectiveAccountId;
    }
    const untrustedConfig_excludeEntitlement = untrustedConfig.excludeEntitlement;
    if (typeof untrustedConfig_excludeEntitlement === 'boolean') {
        config.excludeEntitlement = untrustedConfig_excludeEntitlement;
    }
    const untrustedConfig_excludeFields = untrustedConfig.excludeFields;
    if (typeof untrustedConfig_excludeFields === 'boolean') {
        config.excludeFields = untrustedConfig_excludeFields;
    }
    const untrustedConfig_excludeMedia = untrustedConfig.excludeMedia;
    if (typeof untrustedConfig_excludeMedia === 'boolean') {
        config.excludeMedia = untrustedConfig_excludeMedia;
    }
    const untrustedConfig_excludePrimaryProductCategory = untrustedConfig.excludePrimaryProductCategory;
    if (typeof untrustedConfig_excludePrimaryProductCategory === 'boolean') {
        config.excludePrimaryProductCategory = untrustedConfig_excludePrimaryProductCategory;
    }
    const untrustedConfig_fields = untrustedConfig.fields;
    if (ArrayIsArray(untrustedConfig_fields)) {
        const untrustedConfig_fields_array = [];
        for (let i = 0, arrayLength = untrustedConfig_fields.length; i < arrayLength; i++) {
            const untrustedConfig_fields_item = untrustedConfig_fields[i];
            if (typeof untrustedConfig_fields_item === 'string') {
                untrustedConfig_fields_array.push(untrustedConfig_fields_item);
            }
        }
        config.fields = untrustedConfig_fields_array;
    }
    const untrustedConfig_mediaGroups = untrustedConfig.mediaGroups;
    if (ArrayIsArray(untrustedConfig_mediaGroups)) {
        const untrustedConfig_mediaGroups_array = [];
        for (let i = 0, arrayLength = untrustedConfig_mediaGroups.length; i < arrayLength; i++) {
            const untrustedConfig_mediaGroups_item = untrustedConfig_mediaGroups[i];
            if (typeof untrustedConfig_mediaGroups_item === 'string') {
                untrustedConfig_mediaGroups_array.push(untrustedConfig_mediaGroups_item);
            }
        }
        config.mediaGroups = untrustedConfig_mediaGroups_array;
    }
    return config;
}
function validateAdapterConfig$1(untrustedConfig, configPropertyNames) {
    if (!untrustedIsObject(untrustedConfig)) {
        return null;
    }
    if (process.env.NODE_ENV !== 'production') {
        validateConfig(untrustedConfig, configPropertyNames);
    }
    const config = typeCheckConfig$1(untrustedConfig);
    if (!areRequiredParametersPresent(config, configPropertyNames)) {
        return null;
    }
    return config;
}
function buildInMemorySnapshot$1(lds, config) {
    const resourceParams = createResourceParams$1(config);
    const selector = {
        recordId: keyBuilder$1(resourceParams),
        node: select$3(),
        variables: {},
    };
    return lds.storeLookup(selector, {
        config,
        resolve: () => buildNetworkSnapshot$1(lds, config, snapshotRefreshOptions)
    });
}
function onResourceResponseSuccess$1(lds, config, resourceParams, request, response) {
    const snapshot = ingestSuccess$1(lds, resourceParams, request, response, {
        config,
        resolve: () => buildNetworkSnapshot$1(lds, config, snapshotRefreshOptions)
    });
    lds.storeBroadcast();
    return snapshot;
}
function onResourceResponseError$1(lds, config, resourceParams, response) {
    const snapshot = ingestError$1(lds, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$1(lds, config, snapshotRefreshOptions)
    });
    lds.storeBroadcast();
    return snapshot;
}
function buildNetworkSnapshot$1(lds, config, override) {
    const resourceParams = createResourceParams$1(config);
    const request = createResourceRequest$1(resourceParams);
    return lds.dispatchResourceRequest(request, override)
        .then((response) => {
        return onResourceResponseSuccess$1(lds, config, resourceParams, request, response);
    }, (response) => {
        return onResourceResponseError$1(lds, config, resourceParams, response);
    });
}
function resolveUnfulfilledSnapshot$1(lds, config, snapshot) {
    const resourceParams = createResourceParams$1(config);
    const request = createResourceRequest$1(resourceParams);
    return lds.resolveUnfulfilledSnapshot(request, snapshot)
        .then((response) => {
        return onResourceResponseSuccess$1(lds, config, resourceParams, request, response);
    }, (response) => {
        return onResourceResponseError$1(lds, config, resourceParams, response);
    });
}
const getProductAdapterFactory = (lds) => function getProduct(untrustedConfig) {
    const config = validateAdapterConfig$1(untrustedConfig, getProduct_ConfigPropertyNames);
    // Invalid or incomplete config
    if (config === null) {
        return null;
    }
    const cacheSnapshot = buildInMemorySnapshot$1(lds, config);
    // Cache Hit
    if (lds.snapshotDataAvailable(cacheSnapshot) === true) {
        return cacheSnapshot;
    }
    if (cacheSnapshot.state === SNAPSHOT_STATE_UNFULFILLED) {
        return resolveUnfulfilledSnapshot$1(lds, config, cacheSnapshot);
    }
    return buildNetworkSnapshot$1(lds, config);
};

const getProductCategoryPath = createWireAdapterConstructor(adapterName, getProductCategoryPathAdapterFactory);
const getProduct = createWireAdapterConstructor(adapterName$1, getProductAdapterFactory);

export { getProduct, getProductCategoryPath };
