/*  *******************************************************************************************
 *  ATTENTION!
 *  THIS IS A GENERATED FILE FROM https://github.com/salesforce/lds-lightning-platform
 *  If you would like to contribute to LDS, please follow the steps outlined in the git repo.
 *  Any changes made to this file in p4 will be automatically overwritten.
 *  *******************************************************************************************
 */
/* proxy-compat-disable */
import { createWireAdapterConstructor } from 'force/ldsBindings';

const { hasOwnProperty: ObjectPrototypeHasOwnProperty } = Object.prototype;
const { keys: ObjectKeys, freeze: ObjectFreeze } = Object;
const { isArray: ArrayIsArray } = Array;
/**
 * Validates an adapter config is well-formed.
 * @param config The config to validate.
 * @param adapter The adapter validation configuration.
 * @param oneOf The keys the config must contain at least one of.
 * @throws A TypeError if config doesn't satisfy the adapter's config validation.
 */
function validateConfig(config, adapter, oneOf) {
    const { displayName } = adapter;
    const { required, optional, unsupported } = adapter.parameters;
    if (config === undefined ||
        required.every(req => ObjectPrototypeHasOwnProperty.call(config, req)) === false) {
        throw new TypeError(`adapter ${displayName} configuration must specify ${required.sort().join(', ')}`);
    }
    if (oneOf && oneOf.some(req => ObjectPrototypeHasOwnProperty.call(config, req)) === false) {
        throw new TypeError(`adapter ${displayName} configuration must specify one of ${oneOf.sort().join(', ')}`);
    }
    if (unsupported !== undefined &&
        unsupported.some(req => ObjectPrototypeHasOwnProperty.call(config, req))) {
        throw new TypeError(`adapter ${displayName} does not yet support ${unsupported.sort().join(', ')}`);
    }
    const supported = required.concat(optional);
    if (ObjectKeys(config).some(key => !supported.includes(key))) {
        throw new TypeError(`adapter ${displayName} configuration supports only ${supported.sort().join(', ')}`);
    }
}
function untrustedIsObject(untrusted) {
    return typeof untrusted === 'object' && untrusted !== null && ArrayIsArray(untrusted) === false;
}
function areRequiredParametersPresent(config, configPropertyNames) {
    return configPropertyNames.parameters.required.every(req => req in config);
}
const SNAPSHOT_STATE_UNFULFILLED = 'Unfulfilled';
const snapshotRefreshOptions = {
    headers: {
        'Cache-Control': 'no-cache',
    },
};
const keyPrefix = 'Commerce::';

const { freeze: ObjectFreeze$1, keys: ObjectKeys$1 } = Object;
const { isArray: ArrayIsArray$1 } = Array;
const { stringify: JSONStrinify } = JSON;
function createLink(ref) {
    return {
        __ref: ref,
    };
}

function validate(obj, path = 'SearchCategoryRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray$1(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_children = obj.children;
        const path_children = path + '.children';
        if (!ArrayIsArray$1(obj_children)) {
            return new TypeError('Expected "array" but received "' + typeof obj_children + '" (at "' + path_children + '")');
        }
        for (let i = 0; i < obj_children.length; i++) {
            const obj_children_item = obj_children[i];
            const path_children_item = path_children + '[' + i + ']';
            const referenceSearchCategoryRepresentationValidationError = validate(obj_children_item, path_children_item);
            if (referenceSearchCategoryRepresentationValidationError !== null) {
                let message = 'Object doesn\'t match SearchCategoryRepresentation (at "' + path_children_item + '")\n';
                message += referenceSearchCategoryRepresentationValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
                return new TypeError(message);
            }
        }
        const obj_productCount = obj.productCount;
        const path_productCount = path + '.productCount';
        if (typeof obj_productCount !== 'number' || (typeof obj_productCount === 'number' && Math.floor(obj_productCount) !== obj_productCount)) {
            return new TypeError('Expected "integer" but received "' + typeof obj_productCount + '" (at "' + path_productCount + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}
function deepFreeze(input) {
    const input_children = input.children;
    for (let i = 0; i < input_children.length; i++) {
        const input_children_item = input_children[i];
        deepFreeze(input_children_item);
    }
    ObjectFreeze$1(input_children);
    ObjectFreeze$1(input);
}

var DiscriminatorValues;
(function (DiscriminatorValues) {
    DiscriminatorValues["DistinctValue"] = "DistinctValue";
})(DiscriminatorValues || (DiscriminatorValues = {}));

var DiscriminatorValues$1;
(function (DiscriminatorValues) {
    DiscriminatorValues["DistinctValue"] = "DistinctValue";
})(DiscriminatorValues$1 || (DiscriminatorValues$1 = {}));
function validate$1(obj, path = 'SearchFacetRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray$1(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        if (obj.attributeType !== undefined) {
            const obj_attributeType = obj.attributeType;
            const path_attributeType = path + '.attributeType';
            if (typeof obj_attributeType !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_attributeType + '" (at "' + path_attributeType + '")');
            }
        }
        const obj_displayName = obj.displayName;
        const path_displayName = path + '.displayName';
        if (typeof obj_displayName !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_displayName + '" (at "' + path_displayName + '")');
        }
        const obj_displayRank = obj.displayRank;
        const path_displayRank = path + '.displayRank';
        if (typeof obj_displayRank !== 'number' || (typeof obj_displayRank === 'number' && Math.floor(obj_displayRank) !== obj_displayRank)) {
            return new TypeError('Expected "integer" but received "' + typeof obj_displayRank + '" (at "' + path_displayRank + '")');
        }
        const obj_displayType = obj.displayType;
        const path_displayType = path + '.displayType';
        if (typeof obj_displayType !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_displayType + '" (at "' + path_displayType + '")');
        }
        if (obj.facetType !== undefined) {
            const obj_facetType = obj.facetType;
            const path_facetType = path + '.facetType';
            if (typeof obj_facetType !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_facetType + '" (at "' + path_facetType + '")');
            }
        }
        const obj_nameOrId = obj.nameOrId;
        const path_nameOrId = path + '.nameOrId';
        if (typeof obj_nameOrId !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_nameOrId + '" (at "' + path_nameOrId + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}
function deepFreeze$1(input) {
    ObjectFreeze$1(input);
}

function validate$2(obj, path = 'ProductSummaryRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray$1(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_fields = obj.fields;
        const path_fields = path + '.fields';
        if (typeof obj_fields !== 'object' || ArrayIsArray$1(obj_fields) || obj_fields === null) {
            return new TypeError('Expected "object" but received "' + typeof obj_fields + '" (at "' + path_fields + '")');
        }
        const obj_fields_keys = ObjectKeys$1(obj_fields);
        for (let i = 0; i < obj_fields_keys.length; i++) {
            const key = obj_fields_keys[i];
            const obj_fields_prop = obj_fields[key];
            const path_fields_prop = path_fields + '["' + key + '"]';
            let obj_fields_prop_union0 = null;
            const obj_fields_prop_union0_error = (() => {
                if (typeof obj_fields_prop !== 'string') {
                    return new TypeError('Expected "string" but received "' + typeof obj_fields_prop + '" (at "' + path_fields_prop + '")');
                }
            })();
            if (obj_fields_prop_union0_error != null) {
                obj_fields_prop_union0 = obj_fields_prop_union0_error.message;
            }
            let obj_fields_prop_union1 = null;
            const obj_fields_prop_union1_error = (() => {
                if (obj_fields_prop !== null) {
                    return new TypeError('Expected "null" but received "' + typeof obj_fields_prop + '" (at "' + path_fields_prop + '")');
                }
            })();
            if (obj_fields_prop_union1_error != null) {
                obj_fields_prop_union1 = obj_fields_prop_union1_error.message;
            }
            if (obj_fields_prop_union0 && obj_fields_prop_union1) {
                let message = 'Object doesn\'t match union (at "' + path_fields_prop + '")';
                message += '\n' + obj_fields_prop_union0.split('\n').map((line) => '\t' + line).join('\n');
                message += '\n' + obj_fields_prop_union1.split('\n').map((line) => '\t' + line).join('\n');
                return new TypeError(message);
            }
        }
        const obj_id = obj.id;
        const path_id = path + '.id';
        if (typeof obj_id !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_id + '" (at "' + path_id + '")');
        }
        const obj_name = obj.name;
        const path_name = path + '.name';
        if (typeof obj_name !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_name + '" (at "' + path_name + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}
function deepFreeze$2(input) {
    const input_fields = input.fields;
    const input_fields_keys = Object.keys(input_fields);
    const input_fields_length = input_fields_keys.length;
    for (let i = 0; i < input_fields_length; i++) {
        const key = input_fields_keys[i];
    }
    ObjectFreeze$1(input_fields);
    ObjectFreeze$1(input);
}

function validate$3(obj, path = 'ProductSummaryCollectionRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray$1(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_currencyIsoCode = obj.currencyIsoCode;
        const path_currencyIsoCode = path + '.currencyIsoCode';
        if (typeof obj_currencyIsoCode !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_currencyIsoCode + '" (at "' + path_currencyIsoCode + '")');
        }
        if (obj.pageSize !== undefined) {
            const obj_pageSize = obj.pageSize;
            const path_pageSize = path + '.pageSize';
            if (typeof obj_pageSize !== 'number' || (typeof obj_pageSize === 'number' && Math.floor(obj_pageSize) !== obj_pageSize)) {
                return new TypeError('Expected "integer" but received "' + typeof obj_pageSize + '" (at "' + path_pageSize + '")');
            }
        }
        const obj_products = obj.products;
        const path_products = path + '.products';
        if (!ArrayIsArray$1(obj_products)) {
            return new TypeError('Expected "array" but received "' + typeof obj_products + '" (at "' + path_products + '")');
        }
        for (let i = 0; i < obj_products.length; i++) {
            const obj_products_item = obj_products[i];
            const path_products_item = path_products + '[' + i + ']';
            const referenceProductSummaryRepresentationValidationError = validate$2(obj_products_item, path_products_item);
            if (referenceProductSummaryRepresentationValidationError !== null) {
                let message = 'Object doesn\'t match ProductSummaryRepresentation (at "' + path_products_item + '")\n';
                message += referenceProductSummaryRepresentationValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
                return new TypeError(message);
            }
        }
        const obj_total = obj.total;
        const path_total = path + '.total';
        if (typeof obj_total !== 'number' || (typeof obj_total === 'number' && Math.floor(obj_total) !== obj_total)) {
            return new TypeError('Expected "integer" but received "' + typeof obj_total + '" (at "' + path_total + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}
function deepFreeze$3(input) {
    const input_products = input.products;
    for (let i = 0; i < input_products.length; i++) {
        const input_products_item = input_products[i];
        deepFreeze$2(input_products_item);
    }
    ObjectFreeze$1(input_products);
    ObjectFreeze$1(input);
}

function validate$4(obj, path = 'ProductSearchResultsRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray$1(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_categories = obj.categories;
        const path_categories = path + '.categories';
        const referenceSearchCategoryRepresentationValidationError = validate(obj_categories, path_categories);
        if (referenceSearchCategoryRepresentationValidationError !== null) {
            let message = 'Object doesn\'t match SearchCategoryRepresentation (at "' + path_categories + '")\n';
            message += referenceSearchCategoryRepresentationValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_facets = obj.facets;
        const path_facets = path + '.facets';
        if (!ArrayIsArray$1(obj_facets)) {
            return new TypeError('Expected "array" but received "' + typeof obj_facets + '" (at "' + path_facets + '")');
        }
        for (let i = 0; i < obj_facets.length; i++) {
            const obj_facets_item = obj_facets[i];
            const path_facets_item = path_facets + '[' + i + ']';
            const referenceSearchFacetRepresentationValidationError = validate$1(obj_facets_item, path_facets_item);
            if (referenceSearchFacetRepresentationValidationError !== null) {
                let message = 'Object doesn\'t match SearchFacetRepresentation (at "' + path_facets_item + '")\n';
                message += referenceSearchFacetRepresentationValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
                return new TypeError(message);
            }
        }
        const obj_locale = obj.locale;
        const path_locale = path + '.locale';
        if (typeof obj_locale !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_locale + '" (at "' + path_locale + '")');
        }
        const obj_productsPage = obj.productsPage;
        const path_productsPage = path + '.productsPage';
        const referenceProductSummaryCollectionRepresentationValidationError = validate$3(obj_productsPage, path_productsPage);
        if (referenceProductSummaryCollectionRepresentationValidationError !== null) {
            let message = 'Object doesn\'t match ProductSummaryCollectionRepresentation (at "' + path_productsPage + '")\n';
            message += referenceProductSummaryCollectionRepresentationValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
    })();
    return v_error === undefined ? null : v_error;
}
function normalize(input, existing, path, lds, store, timestamp) {
    return input;
}
const select = function ProductSearchResultsRepresentationSelect() {
    return {
        kind: 'Fragment',
        private: [],
        opaque: true
    };
};
function equals(existing, incoming) {
    if (JSONStrinify(incoming) !== JSONStrinify(existing)) {
        return false;
    }
    return true;
}
function deepFreeze$4(input) {
    const input_categories = input.categories;
    deepFreeze(input_categories);
    const input_facets = input.facets;
    for (let i = 0; i < input_facets.length; i++) {
        const input_facets_item = input_facets[i];
        deepFreeze$1(input_facets_item);
    }
    ObjectFreeze$1(input_facets);
    const input_productsPage = input.productsPage;
    deepFreeze$3(input_productsPage);
    ObjectFreeze$1(input);
}
const ingest = function ProductSearchResultsRepresentationIngest(input, path, lds, store, timestamp) {
    if (process.env.NODE_ENV !== 'production') {
        const validateError = validate$4(input);
        if (validateError !== null) {
            throw validateError;
        }
    }
    const key = path.fullPath;
    let incomingRecord = normalize(input, store.records[key], {
        fullPath: key,
        parent: path.parent
    });
    const existingRecord = store.records[key];
    deepFreeze$4(input);
    if (existingRecord === undefined || equals(existingRecord, incomingRecord) === false) {
        lds.storePublish(key, incomingRecord);
    }
    return createLink(key);
};

function select$1(lds, params) {
    return select();
}
function keyBuilder(params) {
    return keyPrefix + 'ProductSearchResultsRepresentation(' + 'effectiveAccountId:' + params.queryParams.effectiveAccountId + ',' + 'webstoreId:' + params.urlParams.webstoreId + ',' + 'categoryId:' + params.body.categoryId + '::' + 'fields:' + params.body.fields + '::' + 'page:' + params.body.page + '::' + 'pageSize:' + params.body.pageSize + '::' + 'refinements:' + params.body.refinements + '::' + 'searchTerm:' + params.body.searchTerm + '::' + 'sortOrderId:' + params.body.sortOrderId + ')';
}
function ingestSuccess(lds, resourceParams, request, response, snapshotRefresh) {
    const { body } = response;
    const key = keyBuilder(resourceParams);
    lds.storeIngest(key, request, body);
    const snapshot = lds.storeLookup({
        recordId: key,
        node: select$1(),
        variables: {},
    }, snapshotRefresh);
    if (process.env.NODE_ENV !== 'production') {
        if (response.headers !== undefined && snapshot.state !== 'Fulfilled') {
            throw new Error('Invalid network response. Expected resource response to result in Fulfilled snapshot');
        }
        if (!(snapshot.state === 'Fulfilled' || snapshot.state === 'Stale')) {
            throw new Error('Invalid resource response. Expected resource response to result in Fulfilled or Stale snapshot');
        }
    }
    return snapshot;
}
function ingestError(lds, params, error, snapshotRefresh) {
    const key = keyBuilder(params);
    lds.storeIngestFetchResponse(key, error);
    return lds.errorSnapshot(error, snapshotRefresh);
}
function createResourceRequest(config) {
    const headers = {};
    return {
        baseUri: '/services/data/v50.0',
        basePath: '/commerce/webstores/' + config.urlParams.webstoreId + '/search/product-search',
        method: 'post',
        body: config.body,
        urlParams: config.urlParams,
        queryParams: config.queryParams,
        ingest: ingest,
        headers,
    };
}

const adapterName = 'productSearch';
const productSearch_ConfigPropertyNames = {
    displayName: 'productSearch',
    parameters: {
        required: ['webstoreId', 'categoryId', 'fields', 'page', 'pageSize', 'refinements', 'searchTerm', 'sortOrderId'],
        optional: ['effectiveAccountId']
    }
};
function createResourceParams(config) {
    return {
        urlParams: {
            webstoreId: config.webstoreId
        },
        queryParams: {
            effectiveAccountId: config.effectiveAccountId
        },
        body: {
            categoryId: config.categoryId, fields: config.fields, page: config.page, pageSize: config.pageSize, refinements: config.refinements, searchTerm: config.searchTerm, sortOrderId: config.sortOrderId
        }
    };
}
function typeCheckConfig(untrustedConfig) {
    const config = {};
    const untrustedConfig_webstoreId = untrustedConfig.webstoreId;
    if (typeof untrustedConfig_webstoreId === 'string') {
        config.webstoreId = untrustedConfig_webstoreId;
    }
    const untrustedConfig_effectiveAccountId = untrustedConfig.effectiveAccountId;
    if (typeof untrustedConfig_effectiveAccountId === 'string') {
        config.effectiveAccountId = untrustedConfig_effectiveAccountId;
    }
    const untrustedConfig_categoryId = untrustedConfig.categoryId;
    if (typeof untrustedConfig_categoryId === 'string') {
        config.categoryId = untrustedConfig_categoryId;
    }
    const untrustedConfig_fields = untrustedConfig.fields;
    if (ArrayIsArray(untrustedConfig_fields)) {
        const untrustedConfig_fields_array = [];
        for (let i = 0, arrayLength = untrustedConfig_fields.length; i < arrayLength; i++) {
            const untrustedConfig_fields_item = untrustedConfig_fields[i];
            if (typeof untrustedConfig_fields_item === 'string') {
                untrustedConfig_fields_array.push(untrustedConfig_fields_item);
            }
        }
        config.fields = untrustedConfig_fields_array;
    }
    const untrustedConfig_page = untrustedConfig.page;
    if (typeof untrustedConfig_page === 'number' && Math.floor(untrustedConfig_page) === untrustedConfig_page) {
        config.page = untrustedConfig_page;
    }
    const untrustedConfig_pageSize = untrustedConfig.pageSize;
    if (typeof untrustedConfig_pageSize === 'number' && Math.floor(untrustedConfig_pageSize) === untrustedConfig_pageSize) {
        config.pageSize = untrustedConfig_pageSize;
    }
    const untrustedConfig_refinements = untrustedConfig.refinements;
    if (ArrayIsArray(untrustedConfig_refinements)) {
        const untrustedConfig_refinements_array = [];
        for (let i = 0, arrayLength = untrustedConfig_refinements.length; i < arrayLength; i++) {
            const untrustedConfig_refinements_item = untrustedConfig_refinements[i];
            if (untrustedIsObject(untrustedConfig_refinements_item)) {
                const untrustedConfig_refinements_item_object = {};
                if (Object.keys(untrustedConfig_refinements_item_object).length >= 0) {
                    untrustedConfig_refinements_array.push(untrustedConfig_refinements_item_object);
                }
            }
        }
        config.refinements = untrustedConfig_refinements_array;
    }
    const untrustedConfig_searchTerm = untrustedConfig.searchTerm;
    if (typeof untrustedConfig_searchTerm === 'string') {
        config.searchTerm = untrustedConfig_searchTerm;
    }
    const untrustedConfig_sortOrderId = untrustedConfig.sortOrderId;
    if (typeof untrustedConfig_sortOrderId === 'string') {
        config.sortOrderId = untrustedConfig_sortOrderId;
    }
    return config;
}
function validateAdapterConfig(untrustedConfig, configPropertyNames) {
    if (!untrustedIsObject(untrustedConfig)) {
        return null;
    }
    if (process.env.NODE_ENV !== 'production') {
        validateConfig(untrustedConfig, configPropertyNames);
    }
    const config = typeCheckConfig(untrustedConfig);
    if (!areRequiredParametersPresent(config, configPropertyNames)) {
        return null;
    }
    return config;
}
function buildInMemorySnapshot(lds, config) {
    const resourceParams = createResourceParams(config);
    const selector = {
        recordId: keyBuilder(resourceParams),
        node: select$1(),
        variables: {},
    };
    return lds.storeLookup(selector, {
        config,
        resolve: () => buildNetworkSnapshot(lds, config, snapshotRefreshOptions)
    });
}
function onResourceResponseSuccess(lds, config, resourceParams, request, response) {
    const snapshot = ingestSuccess(lds, resourceParams, request, response, {
        config,
        resolve: () => buildNetworkSnapshot(lds, config, snapshotRefreshOptions)
    });
    lds.storeBroadcast();
    return snapshot;
}
function onResourceResponseError(lds, config, resourceParams, response) {
    const snapshot = ingestError(lds, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot(lds, config, snapshotRefreshOptions)
    });
    lds.storeBroadcast();
    return snapshot;
}
function buildNetworkSnapshot(lds, config, override) {
    const resourceParams = createResourceParams(config);
    const request = createResourceRequest(resourceParams);
    return lds.dispatchResourceRequest(request, override)
        .then((response) => {
        return onResourceResponseSuccess(lds, config, resourceParams, request, response);
    }, (response) => {
        return onResourceResponseError(lds, config, resourceParams, response);
    });
}
function resolveUnfulfilledSnapshot(lds, config, snapshot) {
    const resourceParams = createResourceParams(config);
    const request = createResourceRequest(resourceParams);
    return lds.resolveUnfulfilledSnapshot(request, snapshot)
        .then((response) => {
        return onResourceResponseSuccess(lds, config, resourceParams, request, response);
    }, (response) => {
        return onResourceResponseError(lds, config, resourceParams, response);
    });
}
const productSearchAdapterFactory = (lds) => function productSearch(untrustedConfig) {
    const config = validateAdapterConfig(untrustedConfig, productSearch_ConfigPropertyNames);
    // Invalid or incomplete config
    if (config === null) {
        return null;
    }
    const cacheSnapshot = buildInMemorySnapshot(lds, config);
    // Cache Hit
    if (lds.snapshotDataAvailable(cacheSnapshot) === true) {
        return cacheSnapshot;
    }
    if (cacheSnapshot.state === SNAPSHOT_STATE_UNFULFILLED) {
        return resolveUnfulfilledSnapshot(lds, config, cacheSnapshot);
    }
    return buildNetworkSnapshot(lds, config);
};

function validate$5(obj, path = 'SuggestedCompletionRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray$1(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_simpleString = obj.simpleString;
        const path_simpleString = path + '.simpleString';
        if (typeof obj_simpleString !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_simpleString + '" (at "' + path_simpleString + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}
function deepFreeze$5(input) {
    ObjectFreeze$1(input);
}

function validate$6(obj, path = 'ProductSearchSuggestionsResultsRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray$1(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_completions = obj.completions;
        const path_completions = path + '.completions';
        if (!ArrayIsArray$1(obj_completions)) {
            return new TypeError('Expected "array" but received "' + typeof obj_completions + '" (at "' + path_completions + '")');
        }
        for (let i = 0; i < obj_completions.length; i++) {
            const obj_completions_item = obj_completions[i];
            const path_completions_item = path_completions + '[' + i + ']';
            const referenceSuggestedCompletionRepresentationValidationError = validate$5(obj_completions_item, path_completions_item);
            if (referenceSuggestedCompletionRepresentationValidationError !== null) {
                let message = 'Object doesn\'t match SuggestedCompletionRepresentation (at "' + path_completions_item + '")\n';
                message += referenceSuggestedCompletionRepresentationValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
                return new TypeError(message);
            }
        }
        const obj_locale = obj.locale;
        const path_locale = path + '.locale';
        if (typeof obj_locale !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_locale + '" (at "' + path_locale + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}
function normalize$1(input, existing, path, lds, store, timestamp) {
    return input;
}
const select$2 = function ProductSearchSuggestionsResultsRepresentationSelect() {
    return {
        kind: 'Fragment',
        private: [],
        opaque: true
    };
};
function equals$1(existing, incoming) {
    if (JSONStrinify(incoming) !== JSONStrinify(existing)) {
        return false;
    }
    return true;
}
function deepFreeze$6(input) {
    const input_completions = input.completions;
    for (let i = 0; i < input_completions.length; i++) {
        const input_completions_item = input_completions[i];
        deepFreeze$5(input_completions_item);
    }
    ObjectFreeze$1(input_completions);
    ObjectFreeze$1(input);
}
const ingest$1 = function ProductSearchSuggestionsResultsRepresentationIngest(input, path, lds, store, timestamp) {
    if (process.env.NODE_ENV !== 'production') {
        const validateError = validate$6(input);
        if (validateError !== null) {
            throw validateError;
        }
    }
    const key = path.fullPath;
    let incomingRecord = normalize$1(input, store.records[key], {
        fullPath: key,
        parent: path.parent
    });
    const existingRecord = store.records[key];
    deepFreeze$6(input);
    if (existingRecord === undefined || equals$1(existingRecord, incomingRecord) === false) {
        lds.storePublish(key, incomingRecord);
    }
    return createLink(key);
};

function select$3(lds, params) {
    return select$2();
}
function keyBuilder$1(params) {
    return keyPrefix + 'ProductSearchSuggestionsResultsRepresentation(' + 'effectiveAccountId:' + params.queryParams.effectiveAccountId + ',' + 'limit:' + params.queryParams.limit + ',' + 'searchTerm:' + params.queryParams.searchTerm + ',' + 'webstoreId:' + params.urlParams.webstoreId + ')';
}
function ingestSuccess$1(lds, resourceParams, request, response, snapshotRefresh) {
    const { body } = response;
    const key = keyBuilder$1(resourceParams);
    lds.storeIngest(key, request, body);
    const snapshot = lds.storeLookup({
        recordId: key,
        node: select$3(),
        variables: {},
    }, snapshotRefresh);
    if (process.env.NODE_ENV !== 'production') {
        if (response.headers !== undefined && snapshot.state !== 'Fulfilled') {
            throw new Error('Invalid network response. Expected resource response to result in Fulfilled snapshot');
        }
        if (!(snapshot.state === 'Fulfilled' || snapshot.state === 'Stale')) {
            throw new Error('Invalid resource response. Expected resource response to result in Fulfilled or Stale snapshot');
        }
    }
    return snapshot;
}
function ingestError$1(lds, params, error, snapshotRefresh) {
    const key = keyBuilder$1(params);
    lds.storeIngestFetchResponse(key, error);
    return lds.errorSnapshot(error, snapshotRefresh);
}
function createResourceRequest$1(config) {
    const headers = {};
    return {
        baseUri: '/services/data/v50.0',
        basePath: '/commerce/webstores/' + config.urlParams.webstoreId + '/search/suggestions',
        method: 'get',
        body: null,
        urlParams: config.urlParams,
        queryParams: config.queryParams,
        ingest: ingest$1,
        headers,
    };
}

const adapterName$1 = 'getSuggestions';
const getSuggestions_ConfigPropertyNames = {
    displayName: 'getSuggestions',
    parameters: {
        required: ['webstoreId'],
        optional: ['effectiveAccountId', 'limit', 'searchTerm']
    }
};
function createResourceParams$1(config) {
    return {
        urlParams: {
            webstoreId: config.webstoreId
        },
        queryParams: {
            effectiveAccountId: config.effectiveAccountId, limit: config.limit, searchTerm: config.searchTerm
        }
    };
}
function typeCheckConfig$1(untrustedConfig) {
    const config = {};
    const untrustedConfig_webstoreId = untrustedConfig.webstoreId;
    if (typeof untrustedConfig_webstoreId === 'string') {
        config.webstoreId = untrustedConfig_webstoreId;
    }
    const untrustedConfig_effectiveAccountId = untrustedConfig.effectiveAccountId;
    if (typeof untrustedConfig_effectiveAccountId === 'string') {
        config.effectiveAccountId = untrustedConfig_effectiveAccountId;
    }
    const untrustedConfig_limit = untrustedConfig.limit;
    if (typeof untrustedConfig_limit === 'number' && Math.floor(untrustedConfig_limit) === untrustedConfig_limit) {
        config.limit = untrustedConfig_limit;
    }
    const untrustedConfig_searchTerm = untrustedConfig.searchTerm;
    if (typeof untrustedConfig_searchTerm === 'string') {
        config.searchTerm = untrustedConfig_searchTerm;
    }
    return config;
}
function validateAdapterConfig$1(untrustedConfig, configPropertyNames) {
    if (!untrustedIsObject(untrustedConfig)) {
        return null;
    }
    if (process.env.NODE_ENV !== 'production') {
        validateConfig(untrustedConfig, configPropertyNames);
    }
    const config = typeCheckConfig$1(untrustedConfig);
    if (!areRequiredParametersPresent(config, configPropertyNames)) {
        return null;
    }
    return config;
}
function buildInMemorySnapshot$1(lds, config) {
    const resourceParams = createResourceParams$1(config);
    const selector = {
        recordId: keyBuilder$1(resourceParams),
        node: select$3(),
        variables: {},
    };
    return lds.storeLookup(selector, {
        config,
        resolve: () => buildNetworkSnapshot$1(lds, config, snapshotRefreshOptions)
    });
}
function onResourceResponseSuccess$1(lds, config, resourceParams, request, response) {
    const snapshot = ingestSuccess$1(lds, resourceParams, request, response, {
        config,
        resolve: () => buildNetworkSnapshot$1(lds, config, snapshotRefreshOptions)
    });
    lds.storeBroadcast();
    return snapshot;
}
function onResourceResponseError$1(lds, config, resourceParams, response) {
    const snapshot = ingestError$1(lds, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$1(lds, config, snapshotRefreshOptions)
    });
    lds.storeBroadcast();
    return snapshot;
}
function buildNetworkSnapshot$1(lds, config, override) {
    const resourceParams = createResourceParams$1(config);
    const request = createResourceRequest$1(resourceParams);
    return lds.dispatchResourceRequest(request, override)
        .then((response) => {
        return onResourceResponseSuccess$1(lds, config, resourceParams, request, response);
    }, (response) => {
        return onResourceResponseError$1(lds, config, resourceParams, response);
    });
}
function resolveUnfulfilledSnapshot$1(lds, config, snapshot) {
    const resourceParams = createResourceParams$1(config);
    const request = createResourceRequest$1(resourceParams);
    return lds.resolveUnfulfilledSnapshot(request, snapshot)
        .then((response) => {
        return onResourceResponseSuccess$1(lds, config, resourceParams, request, response);
    }, (response) => {
        return onResourceResponseError$1(lds, config, resourceParams, response);
    });
}
const getSuggestionsAdapterFactory = (lds) => function getSuggestions(untrustedConfig) {
    const config = validateAdapterConfig$1(untrustedConfig, getSuggestions_ConfigPropertyNames);
    // Invalid or incomplete config
    if (config === null) {
        return null;
    }
    const cacheSnapshot = buildInMemorySnapshot$1(lds, config);
    // Cache Hit
    if (lds.snapshotDataAvailable(cacheSnapshot) === true) {
        return cacheSnapshot;
    }
    if (cacheSnapshot.state === SNAPSHOT_STATE_UNFULFILLED) {
        return resolveUnfulfilledSnapshot$1(lds, config, cacheSnapshot);
    }
    return buildNetworkSnapshot$1(lds, config);
};

const productSearch = createWireAdapterConstructor(adapterName, productSearchAdapterFactory);
const getSuggestions = createWireAdapterConstructor(adapterName$1, getSuggestionsAdapterFactory);

export { getSuggestions, productSearch };
