/*  *******************************************************************************************
 *  ATTENTION!
 *  THIS IS A GENERATED FILE FROM https://github.com/salesforce/lds-lightning-platform
 *  If you would like to contribute to LDS, please follow the steps outlined in the git repo.
 *  Any changes made to this file in p4 will be automatically overwritten.
 *  *******************************************************************************************
 */
/* proxy-compat-disable */
import { createWireAdapterConstructor } from 'force/ldsBindings';

const { hasOwnProperty: ObjectPrototypeHasOwnProperty } = Object.prototype;
const { keys: ObjectKeys, freeze: ObjectFreeze } = Object;
const { isArray: ArrayIsArray } = Array;
/**
 * Validates an adapter config is well-formed.
 * @param config The config to validate.
 * @param adapter The adapter validation configuration.
 * @param oneOf The keys the config must contain at least one of.
 * @throws A TypeError if config doesn't satisfy the adapter's config validation.
 */
function validateConfig(config, adapter, oneOf) {
    const { displayName } = adapter;
    const { required, optional, unsupported } = adapter.parameters;
    if (config === undefined ||
        required.every(req => ObjectPrototypeHasOwnProperty.call(config, req)) === false) {
        throw new TypeError(`adapter ${displayName} configuration must specify ${required.sort().join(', ')}`);
    }
    if (oneOf && oneOf.some(req => ObjectPrototypeHasOwnProperty.call(config, req)) === false) {
        throw new TypeError(`adapter ${displayName} configuration must specify one of ${oneOf.sort().join(', ')}`);
    }
    if (unsupported !== undefined &&
        unsupported.some(req => ObjectPrototypeHasOwnProperty.call(config, req))) {
        throw new TypeError(`adapter ${displayName} does not yet support ${unsupported.sort().join(', ')}`);
    }
    const supported = required.concat(optional);
    if (ObjectKeys(config).some(key => !supported.includes(key))) {
        throw new TypeError(`adapter ${displayName} configuration supports only ${supported.sort().join(', ')}`);
    }
}
function untrustedIsObject(untrusted) {
    return typeof untrusted === 'object' && untrusted !== null && ArrayIsArray(untrusted) === false;
}
function areRequiredParametersPresent(config, configPropertyNames) {
    return configPropertyNames.parameters.required.every(req => req in config);
}
const SNAPSHOT_STATE_UNFULFILLED = 'Unfulfilled';
const snapshotRefreshOptions = {
    headers: {
        'Cache-Control': 'no-cache',
    },
};
const keyPrefix = 'Commerce::';

const { freeze: ObjectFreeze$1, keys: ObjectKeys$1 } = Object;
const { isArray: ArrayIsArray$1 } = Array;
const { stringify: JSONStrinify } = JSON;
function createLink(ref) {
    return {
        __ref: ref,
    };
}

function validate(obj, path = 'PriceAdjustmentTierRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray$1(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_adjustmentType = obj.adjustmentType;
        const path_adjustmentType = path + '.adjustmentType';
        if (typeof obj_adjustmentType !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_adjustmentType + '" (at "' + path_adjustmentType + '")');
        }
        const obj_adjustmentValue = obj.adjustmentValue;
        const path_adjustmentValue = path + '.adjustmentValue';
        if (typeof obj_adjustmentValue !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_adjustmentValue + '" (at "' + path_adjustmentValue + '")');
        }
        const obj_id = obj.id;
        const path_id = path + '.id';
        if (typeof obj_id !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_id + '" (at "' + path_id + '")');
        }
        const obj_lowerBound = obj.lowerBound;
        const path_lowerBound = path + '.lowerBound';
        if (typeof obj_lowerBound !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_lowerBound + '" (at "' + path_lowerBound + '")');
        }
        const obj_tierUnitPrice = obj.tierUnitPrice;
        const path_tierUnitPrice = path + '.tierUnitPrice';
        if (typeof obj_tierUnitPrice !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_tierUnitPrice + '" (at "' + path_tierUnitPrice + '")');
        }
        const obj_upperBound = obj.upperBound;
        const path_upperBound = path + '.upperBound';
        if (typeof obj_upperBound !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_upperBound + '" (at "' + path_upperBound + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}
function deepFreeze(input) {
    ObjectFreeze$1(input);
}

function validate$1(obj, path = 'PriceAdjustmentScheduleRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray$1(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_id = obj.id;
        const path_id = path + '.id';
        if (typeof obj_id !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_id + '" (at "' + path_id + '")');
        }
        const obj_priceAdjustmentTiers = obj.priceAdjustmentTiers;
        const path_priceAdjustmentTiers = path + '.priceAdjustmentTiers';
        if (!ArrayIsArray$1(obj_priceAdjustmentTiers)) {
            return new TypeError('Expected "array" but received "' + typeof obj_priceAdjustmentTiers + '" (at "' + path_priceAdjustmentTiers + '")');
        }
        for (let i = 0; i < obj_priceAdjustmentTiers.length; i++) {
            const obj_priceAdjustmentTiers_item = obj_priceAdjustmentTiers[i];
            const path_priceAdjustmentTiers_item = path_priceAdjustmentTiers + '[' + i + ']';
            const referencePriceAdjustmentTierRepresentationValidationError = validate(obj_priceAdjustmentTiers_item, path_priceAdjustmentTiers_item);
            if (referencePriceAdjustmentTierRepresentationValidationError !== null) {
                let message = 'Object doesn\'t match PriceAdjustmentTierRepresentation (at "' + path_priceAdjustmentTiers_item + '")\n';
                message += referencePriceAdjustmentTierRepresentationValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
                return new TypeError(message);
            }
        }
    })();
    return v_error === undefined ? null : v_error;
}
function deepFreeze$1(input) {
    const input_priceAdjustmentTiers = input.priceAdjustmentTiers;
    for (let i = 0; i < input_priceAdjustmentTiers.length; i++) {
        const input_priceAdjustmentTiers_item = input_priceAdjustmentTiers[i];
        deepFreeze(input_priceAdjustmentTiers_item);
    }
    ObjectFreeze$1(input_priceAdjustmentTiers);
    ObjectFreeze$1(input);
}

function validate$2(obj, path = 'ProductPriceRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray$1(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_currencyIsoCode = obj.currencyIsoCode;
        const path_currencyIsoCode = path + '.currencyIsoCode';
        if (typeof obj_currencyIsoCode !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_currencyIsoCode + '" (at "' + path_currencyIsoCode + '")');
        }
        const obj_listPrice = obj.listPrice;
        const path_listPrice = path + '.listPrice';
        if (typeof obj_listPrice !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_listPrice + '" (at "' + path_listPrice + '")');
        }
        const obj_priceAdjustment = obj.priceAdjustment;
        const path_priceAdjustment = path + '.priceAdjustment';
        let obj_priceAdjustment_union0 = null;
        const obj_priceAdjustment_union0_error = (() => {
            const referencePriceAdjustmentScheduleRepresentationValidationError = validate$1(obj_priceAdjustment, path_priceAdjustment);
            if (referencePriceAdjustmentScheduleRepresentationValidationError !== null) {
                let message = 'Object doesn\'t match PriceAdjustmentScheduleRepresentation (at "' + path_priceAdjustment + '")\n';
                message += referencePriceAdjustmentScheduleRepresentationValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
                return new TypeError(message);
            }
        })();
        if (obj_priceAdjustment_union0_error != null) {
            obj_priceAdjustment_union0 = obj_priceAdjustment_union0_error.message;
        }
        let obj_priceAdjustment_union1 = null;
        const obj_priceAdjustment_union1_error = (() => {
            if (obj_priceAdjustment !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_priceAdjustment + '" (at "' + path_priceAdjustment + '")');
            }
        })();
        if (obj_priceAdjustment_union1_error != null) {
            obj_priceAdjustment_union1 = obj_priceAdjustment_union1_error.message;
        }
        if (obj_priceAdjustment_union0 && obj_priceAdjustment_union1) {
            let message = 'Object doesn\'t match union (at "' + path_priceAdjustment + '")';
            message += '\n' + obj_priceAdjustment_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_priceAdjustment_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_pricebookEntryId = obj.pricebookEntryId;
        const path_pricebookEntryId = path + '.pricebookEntryId';
        if (typeof obj_pricebookEntryId !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_pricebookEntryId + '" (at "' + path_pricebookEntryId + '")');
        }
        const obj_unitPrice = obj.unitPrice;
        const path_unitPrice = path + '.unitPrice';
        if (typeof obj_unitPrice !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_unitPrice + '" (at "' + path_unitPrice + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}
function normalize(input, existing, path, lds, store, timestamp) {
    return input;
}
const select = function ProductPriceRepresentationSelect() {
    return {
        kind: 'Fragment',
        private: [],
        opaque: true
    };
};
function equals(existing, incoming) {
    if (JSONStrinify(incoming) !== JSONStrinify(existing)) {
        return false;
    }
    return true;
}
function deepFreeze$2(input) {
    const input_priceAdjustment = input.priceAdjustment;
    if (input_priceAdjustment !== null && typeof input_priceAdjustment === 'object') {
        deepFreeze$1(input_priceAdjustment);
    }
    ObjectFreeze$1(input);
}
const ingest = function ProductPriceRepresentationIngest(input, path, lds, store, timestamp) {
    if (process.env.NODE_ENV !== 'production') {
        const validateError = validate$2(input);
        if (validateError !== null) {
            throw validateError;
        }
    }
    const key = path.fullPath;
    let incomingRecord = normalize(input, store.records[key], {
        fullPath: key,
        parent: path.parent
    });
    const existingRecord = store.records[key];
    deepFreeze$2(input);
    if (existingRecord === undefined || equals(existingRecord, incomingRecord) === false) {
        lds.storePublish(key, incomingRecord);
    }
    return createLink(key);
};

function select$1(lds, params) {
    return select();
}
function keyBuilder(params) {
    return keyPrefix + 'ProductPriceRepresentation(' + 'effectiveAccountId:' + params.queryParams.effectiveAccountId + ',' + 'productId:' + params.urlParams.productId + ',' + 'webstoreId:' + params.urlParams.webstoreId + ')';
}
function ingestSuccess(lds, resourceParams, request, response, snapshotRefresh) {
    const { body } = response;
    const key = keyBuilder(resourceParams);
    lds.storeIngest(key, request, body);
    const snapshot = lds.storeLookup({
        recordId: key,
        node: select$1(),
        variables: {},
    }, snapshotRefresh);
    if (process.env.NODE_ENV !== 'production') {
        if (response.headers !== undefined && snapshot.state !== 'Fulfilled') {
            throw new Error('Invalid network response. Expected resource response to result in Fulfilled snapshot');
        }
        if (!(snapshot.state === 'Fulfilled' || snapshot.state === 'Stale')) {
            throw new Error('Invalid resource response. Expected resource response to result in Fulfilled or Stale snapshot');
        }
    }
    return snapshot;
}
function ingestError(lds, params, error, snapshotRefresh) {
    const key = keyBuilder(params);
    lds.storeIngestFetchResponse(key, error);
    return lds.errorSnapshot(error, snapshotRefresh);
}
function createResourceRequest(config) {
    const headers = {};
    return {
        baseUri: '/services/data/v50.0',
        basePath: '/commerce/webstores/' + config.urlParams.webstoreId + '/pricing/products/' + config.urlParams.productId + '',
        method: 'get',
        body: null,
        urlParams: config.urlParams,
        queryParams: config.queryParams,
        ingest: ingest,
        headers,
    };
}

const adapterName = 'getProductPrice';
const getProductPrice_ConfigPropertyNames = {
    displayName: 'getProductPrice',
    parameters: {
        required: ['productId', 'webstoreId', 'effectiveAccountId'],
        optional: []
    }
};
function createResourceParams(config) {
    return {
        urlParams: {
            productId: config.productId, webstoreId: config.webstoreId
        },
        queryParams: {
            effectiveAccountId: config.effectiveAccountId
        }
    };
}
function typeCheckConfig(untrustedConfig) {
    const config = {};
    const untrustedConfig_productId = untrustedConfig.productId;
    if (typeof untrustedConfig_productId === 'string') {
        config.productId = untrustedConfig_productId;
    }
    const untrustedConfig_webstoreId = untrustedConfig.webstoreId;
    if (typeof untrustedConfig_webstoreId === 'string') {
        config.webstoreId = untrustedConfig_webstoreId;
    }
    const untrustedConfig_effectiveAccountId = untrustedConfig.effectiveAccountId;
    if (typeof untrustedConfig_effectiveAccountId === 'string') {
        config.effectiveAccountId = untrustedConfig_effectiveAccountId;
    }
    return config;
}
function validateAdapterConfig(untrustedConfig, configPropertyNames) {
    if (!untrustedIsObject(untrustedConfig)) {
        return null;
    }
    if (process.env.NODE_ENV !== 'production') {
        validateConfig(untrustedConfig, configPropertyNames);
    }
    const config = typeCheckConfig(untrustedConfig);
    if (!areRequiredParametersPresent(config, configPropertyNames)) {
        return null;
    }
    return config;
}
function buildInMemorySnapshot(lds, config) {
    const resourceParams = createResourceParams(config);
    const selector = {
        recordId: keyBuilder(resourceParams),
        node: select$1(),
        variables: {},
    };
    return lds.storeLookup(selector, {
        config,
        resolve: () => buildNetworkSnapshot(lds, config, snapshotRefreshOptions)
    });
}
function onResourceResponseSuccess(lds, config, resourceParams, request, response) {
    const snapshot = ingestSuccess(lds, resourceParams, request, response, {
        config,
        resolve: () => buildNetworkSnapshot(lds, config, snapshotRefreshOptions)
    });
    lds.storeBroadcast();
    return snapshot;
}
function onResourceResponseError(lds, config, resourceParams, response) {
    const snapshot = ingestError(lds, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot(lds, config, snapshotRefreshOptions)
    });
    lds.storeBroadcast();
    return snapshot;
}
function buildNetworkSnapshot(lds, config, override) {
    const resourceParams = createResourceParams(config);
    const request = createResourceRequest(resourceParams);
    return lds.dispatchResourceRequest(request, override)
        .then((response) => {
        return onResourceResponseSuccess(lds, config, resourceParams, request, response);
    }, (response) => {
        return onResourceResponseError(lds, config, resourceParams, response);
    });
}
function resolveUnfulfilledSnapshot(lds, config, snapshot) {
    const resourceParams = createResourceParams(config);
    const request = createResourceRequest(resourceParams);
    return lds.resolveUnfulfilledSnapshot(request, snapshot)
        .then((response) => {
        return onResourceResponseSuccess(lds, config, resourceParams, request, response);
    }, (response) => {
        return onResourceResponseError(lds, config, resourceParams, response);
    });
}
const getProductPriceAdapterFactory = (lds) => function getProductPrice(untrustedConfig) {
    const config = validateAdapterConfig(untrustedConfig, getProductPrice_ConfigPropertyNames);
    // Invalid or incomplete config
    if (config === null) {
        return null;
    }
    const cacheSnapshot = buildInMemorySnapshot(lds, config);
    // Cache Hit
    if (lds.snapshotDataAvailable(cacheSnapshot) === true) {
        return cacheSnapshot;
    }
    if (cacheSnapshot.state === SNAPSHOT_STATE_UNFULFILLED) {
        return resolveUnfulfilledSnapshot(lds, config, cacheSnapshot);
    }
    return buildNetworkSnapshot(lds, config);
};

const getProductPrice = createWireAdapterConstructor(adapterName, getProductPriceAdapterFactory);

export { getProductPrice };
