/*  *******************************************************************************************
 *  ATTENTION!
 *  THIS IS A GENERATED FILE FROM https://github.com/salesforce/lds-lightning-platform
 *  If you would like to contribute to LDS, please follow the steps outlined in the git repo.
 *  Any changes made to this file in p4 will be automatically overwritten.
 *  *******************************************************************************************
 */
/* proxy-compat-disable */
import { createWireAdapterConstructor } from 'force/ldsBindings';

const { hasOwnProperty: ObjectPrototypeHasOwnProperty } = Object.prototype;
const { keys: ObjectKeys, freeze: ObjectFreeze } = Object;
const { isArray: ArrayIsArray } = Array;
/**
 * Validates an adapter config is well-formed.
 * @param config The config to validate.
 * @param adapter The adapter validation configuration.
 * @param oneOf The keys the config must contain at least one of.
 * @throws A TypeError if config doesn't satisfy the adapter's config validation.
 */
function validateConfig(config, adapter, oneOf) {
    const { displayName } = adapter;
    const { required, optional, unsupported } = adapter.parameters;
    if (config === undefined ||
        required.every(req => ObjectPrototypeHasOwnProperty.call(config, req)) === false) {
        throw new TypeError(`adapter ${displayName} configuration must specify ${required.sort().join(', ')}`);
    }
    if (oneOf && oneOf.some(req => ObjectPrototypeHasOwnProperty.call(config, req)) === false) {
        throw new TypeError(`adapter ${displayName} configuration must specify one of ${oneOf.sort().join(', ')}`);
    }
    if (unsupported !== undefined &&
        unsupported.some(req => ObjectPrototypeHasOwnProperty.call(config, req))) {
        throw new TypeError(`adapter ${displayName} does not yet support ${unsupported.sort().join(', ')}`);
    }
    const supported = required.concat(optional);
    if (ObjectKeys(config).some(key => !supported.includes(key))) {
        throw new TypeError(`adapter ${displayName} configuration supports only ${supported.sort().join(', ')}`);
    }
}
function untrustedIsObject(untrusted) {
    return typeof untrusted === 'object' && untrusted !== null && ArrayIsArray(untrusted) === false;
}
function areRequiredParametersPresent(config, configPropertyNames) {
    return configPropertyNames.parameters.required.every(req => req in config);
}
const SNAPSHOT_STATE_UNFULFILLED = 'Unfulfilled';
const snapshotRefreshOptions = {
    headers: {
        'Cache-Control': 'no-cache',
    },
};
const keyPrefix = 'CommunityNavigation::';

const { freeze: ObjectFreeze$1, keys: ObjectKeys$1 } = Object;
const { isArray: ArrayIsArray$1 } = Array;
const { stringify: JSONStrinify } = JSON;
function createLink(ref) {
    return {
        __ref: ref,
    };
}

function validate(obj, path = 'NavigationMenuItemRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray$1(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_actionType = obj.actionType;
        const path_actionType = path + '.actionType';
        if (typeof obj_actionType !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_actionType + '" (at "' + path_actionType + '")');
        }
        const obj_actionValue = obj.actionValue;
        const path_actionValue = path + '.actionValue';
        let obj_actionValue_union0 = null;
        const obj_actionValue_union0_error = (() => {
            if (typeof obj_actionValue !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_actionValue + '" (at "' + path_actionValue + '")');
            }
        })();
        if (obj_actionValue_union0_error != null) {
            obj_actionValue_union0 = obj_actionValue_union0_error.message;
        }
        let obj_actionValue_union1 = null;
        const obj_actionValue_union1_error = (() => {
            if (obj_actionValue !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_actionValue + '" (at "' + path_actionValue + '")');
            }
        })();
        if (obj_actionValue_union1_error != null) {
            obj_actionValue_union1 = obj_actionValue_union1_error.message;
        }
        if (obj_actionValue_union0 && obj_actionValue_union1) {
            let message = 'Object doesn\'t match union (at "' + path_actionValue + '")';
            message += '\n' + obj_actionValue_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_actionValue_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_imageUrl = obj.imageUrl;
        const path_imageUrl = path + '.imageUrl';
        let obj_imageUrl_union0 = null;
        const obj_imageUrl_union0_error = (() => {
            if (typeof obj_imageUrl !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_imageUrl + '" (at "' + path_imageUrl + '")');
            }
        })();
        if (obj_imageUrl_union0_error != null) {
            obj_imageUrl_union0 = obj_imageUrl_union0_error.message;
        }
        let obj_imageUrl_union1 = null;
        const obj_imageUrl_union1_error = (() => {
            if (obj_imageUrl !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_imageUrl + '" (at "' + path_imageUrl + '")');
            }
        })();
        if (obj_imageUrl_union1_error != null) {
            obj_imageUrl_union1 = obj_imageUrl_union1_error.message;
        }
        if (obj_imageUrl_union0 && obj_imageUrl_union1) {
            let message = 'Object doesn\'t match union (at "' + path_imageUrl + '")';
            message += '\n' + obj_imageUrl_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_imageUrl_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_label = obj.label;
        const path_label = path + '.label';
        if (typeof obj_label !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_label + '" (at "' + path_label + '")');
        }
        const obj_subMenu = obj.subMenu;
        const path_subMenu = path + '.subMenu';
        if (!ArrayIsArray$1(obj_subMenu)) {
            return new TypeError('Expected "array" but received "' + typeof obj_subMenu + '" (at "' + path_subMenu + '")');
        }
        for (let i = 0; i < obj_subMenu.length; i++) {
            const obj_subMenu_item = obj_subMenu[i];
            const path_subMenu_item = path_subMenu + '[' + i + ']';
            const referenceNavigationMenuItemRepresentationValidationError = validate(obj_subMenu_item, path_subMenu_item);
            if (referenceNavigationMenuItemRepresentationValidationError !== null) {
                let message = 'Object doesn\'t match NavigationMenuItemRepresentation (at "' + path_subMenu_item + '")\n';
                message += referenceNavigationMenuItemRepresentationValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
                return new TypeError(message);
            }
        }
        const obj_target = obj.target;
        const path_target = path + '.target';
        if (typeof obj_target !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_target + '" (at "' + path_target + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}
function deepFreeze(input) {
    const input_subMenu = input.subMenu;
    for (let i = 0; i < input_subMenu.length; i++) {
        const input_subMenu_item = input_subMenu[i];
        deepFreeze(input_subMenu_item);
    }
    ObjectFreeze$1(input_subMenu);
    ObjectFreeze$1(input);
}

function validate$1(obj, path = 'NavigationMenuItemCollectionRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray$1(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_menuItems = obj.menuItems;
        const path_menuItems = path + '.menuItems';
        if (!ArrayIsArray$1(obj_menuItems)) {
            return new TypeError('Expected "array" but received "' + typeof obj_menuItems + '" (at "' + path_menuItems + '")');
        }
        for (let i = 0; i < obj_menuItems.length; i++) {
            const obj_menuItems_item = obj_menuItems[i];
            const path_menuItems_item = path_menuItems + '[' + i + ']';
            const referenceNavigationMenuItemRepresentationValidationError = validate(obj_menuItems_item, path_menuItems_item);
            if (referenceNavigationMenuItemRepresentationValidationError !== null) {
                let message = 'Object doesn\'t match NavigationMenuItemRepresentation (at "' + path_menuItems_item + '")\n';
                message += referenceNavigationMenuItemRepresentationValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
                return new TypeError(message);
            }
        }
    })();
    return v_error === undefined ? null : v_error;
}
function normalize(input, existing, path, lds, store, timestamp) {
    return input;
}
const select = function NavigationMenuItemCollectionRepresentationSelect() {
    return {
        kind: 'Fragment',
        private: [],
        opaque: true
    };
};
function equals(existing, incoming) {
    if (JSONStrinify(incoming) !== JSONStrinify(existing)) {
        return false;
    }
    return true;
}
function deepFreeze$1(input) {
    const input_menuItems = input.menuItems;
    for (let i = 0; i < input_menuItems.length; i++) {
        const input_menuItems_item = input_menuItems[i];
        deepFreeze(input_menuItems_item);
    }
    ObjectFreeze$1(input_menuItems);
    ObjectFreeze$1(input);
}
const ingest = function NavigationMenuItemCollectionRepresentationIngest(input, path, lds, store, timestamp) {
    if (process.env.NODE_ENV !== 'production') {
        const validateError = validate$1(input);
        if (validateError !== null) {
            throw validateError;
        }
    }
    const key = path.fullPath;
    let incomingRecord = normalize(input, store.records[key], {
        fullPath: key,
        parent: path.parent
    });
    const existingRecord = store.records[key];
    deepFreeze$1(input);
    if (existingRecord === undefined || equals(existingRecord, incomingRecord) === false) {
        lds.storePublish(key, incomingRecord);
    }
    return createLink(key);
};

function select$1(lds, params) {
    return select();
}
function keyBuilder(params) {
    return keyPrefix + 'NavigationMenuItemCollectionRepresentation(' + 'addHomeMenuItem:' + params.queryParams.addHomeMenuItem + ',' + 'includeImageUrl:' + params.queryParams.includeImageUrl + ',' + 'menuItemTypesToSkip:' + params.queryParams.menuItemTypesToSkip + ',' + 'navigationLinkSetDeveloperName:' + params.queryParams.navigationLinkSetDeveloperName + ',' + 'navigationLinkSetId:' + params.queryParams.navigationLinkSetId + ',' + 'publishStatus:' + params.queryParams.publishStatus + ',' + 'communityId:' + params.urlParams.communityId + ')';
}
function ingestSuccess(lds, resourceParams, request, response, snapshotRefresh) {
    const { body } = response;
    const key = keyBuilder(resourceParams);
    lds.storeIngest(key, request, body);
    const snapshot = lds.storeLookup({
        recordId: key,
        node: select$1(),
        variables: {},
    }, snapshotRefresh);
    if (process.env.NODE_ENV !== 'production') {
        if (response.headers !== undefined && snapshot.state !== 'Fulfilled') {
            throw new Error('Invalid network response. Expected resource response to result in Fulfilled snapshot');
        }
        if (!(snapshot.state === 'Fulfilled' || snapshot.state === 'Stale')) {
            throw new Error('Invalid resource response. Expected resource response to result in Fulfilled or Stale snapshot');
        }
    }
    return snapshot;
}
function ingestError(lds, params, error, snapshotRefresh) {
    const key = keyBuilder(params);
    lds.storeIngestFetchResponse(key, error);
    return lds.errorSnapshot(error, snapshotRefresh);
}
function createResourceRequest(config) {
    const headers = {};
    return {
        baseUri: '/services/data/v50.0',
        basePath: '/connect/communities/' + config.urlParams.communityId + '/navigation-menu/navigation-menu-items',
        method: 'get',
        body: null,
        urlParams: config.urlParams,
        queryParams: config.queryParams,
        ingest: ingest,
        headers,
    };
}

const adapterName = 'getCommunityNavigationMenu';
const getCommunityNavigationMenu_ConfigPropertyNames = {
    displayName: 'getCommunityNavigationMenu',
    parameters: {
        required: ['communityId'],
        optional: ['addHomeMenuItem', 'includeImageUrl', 'menuItemTypesToSkip', 'navigationLinkSetDeveloperName', 'navigationLinkSetId', 'publishStatus']
    }
};
function createResourceParams(config) {
    return {
        urlParams: {
            communityId: config.communityId
        },
        queryParams: {
            addHomeMenuItem: config.addHomeMenuItem, includeImageUrl: config.includeImageUrl, menuItemTypesToSkip: config.menuItemTypesToSkip, navigationLinkSetDeveloperName: config.navigationLinkSetDeveloperName, navigationLinkSetId: config.navigationLinkSetId, publishStatus: config.publishStatus
        }
    };
}
function typeCheckConfig(untrustedConfig) {
    const config = {};
    const untrustedConfig_communityId = untrustedConfig.communityId;
    if (typeof untrustedConfig_communityId === 'string') {
        config.communityId = untrustedConfig_communityId;
    }
    const untrustedConfig_addHomeMenuItem = untrustedConfig.addHomeMenuItem;
    if (typeof untrustedConfig_addHomeMenuItem === 'boolean') {
        config.addHomeMenuItem = untrustedConfig_addHomeMenuItem;
    }
    const untrustedConfig_includeImageUrl = untrustedConfig.includeImageUrl;
    if (typeof untrustedConfig_includeImageUrl === 'boolean') {
        config.includeImageUrl = untrustedConfig_includeImageUrl;
    }
    const untrustedConfig_menuItemTypesToSkip = untrustedConfig.menuItemTypesToSkip;
    if (ArrayIsArray(untrustedConfig_menuItemTypesToSkip)) {
        const untrustedConfig_menuItemTypesToSkip_array = [];
        for (let i = 0, arrayLength = untrustedConfig_menuItemTypesToSkip.length; i < arrayLength; i++) {
            const untrustedConfig_menuItemTypesToSkip_item = untrustedConfig_menuItemTypesToSkip[i];
            if (typeof untrustedConfig_menuItemTypesToSkip_item === 'string') {
                untrustedConfig_menuItemTypesToSkip_array.push(untrustedConfig_menuItemTypesToSkip_item);
            }
        }
        config.menuItemTypesToSkip = untrustedConfig_menuItemTypesToSkip_array;
    }
    const untrustedConfig_navigationLinkSetDeveloperName = untrustedConfig.navigationLinkSetDeveloperName;
    if (typeof untrustedConfig_navigationLinkSetDeveloperName === 'string') {
        config.navigationLinkSetDeveloperName = untrustedConfig_navigationLinkSetDeveloperName;
    }
    const untrustedConfig_navigationLinkSetId = untrustedConfig.navigationLinkSetId;
    if (typeof untrustedConfig_navigationLinkSetId === 'string') {
        config.navigationLinkSetId = untrustedConfig_navigationLinkSetId;
    }
    const untrustedConfig_publishStatus = untrustedConfig.publishStatus;
    if (typeof untrustedConfig_publishStatus === 'string') {
        config.publishStatus = untrustedConfig_publishStatus;
    }
    return config;
}
function validateAdapterConfig(untrustedConfig, configPropertyNames) {
    if (!untrustedIsObject(untrustedConfig)) {
        return null;
    }
    if (process.env.NODE_ENV !== 'production') {
        validateConfig(untrustedConfig, configPropertyNames);
    }
    const config = typeCheckConfig(untrustedConfig);
    if (!areRequiredParametersPresent(config, configPropertyNames)) {
        return null;
    }
    return config;
}
function buildInMemorySnapshot(lds, config) {
    const resourceParams = createResourceParams(config);
    const selector = {
        recordId: keyBuilder(resourceParams),
        node: select$1(),
        variables: {},
    };
    return lds.storeLookup(selector, {
        config,
        resolve: () => buildNetworkSnapshot(lds, config, snapshotRefreshOptions)
    });
}
function onResourceResponseSuccess(lds, config, resourceParams, request, response) {
    const snapshot = ingestSuccess(lds, resourceParams, request, response, {
        config,
        resolve: () => buildNetworkSnapshot(lds, config, snapshotRefreshOptions)
    });
    lds.storeBroadcast();
    return snapshot;
}
function onResourceResponseError(lds, config, resourceParams, response) {
    const snapshot = ingestError(lds, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot(lds, config, snapshotRefreshOptions)
    });
    lds.storeBroadcast();
    return snapshot;
}
function buildNetworkSnapshot(lds, config, override) {
    const resourceParams = createResourceParams(config);
    const request = createResourceRequest(resourceParams);
    return lds.dispatchResourceRequest(request, override)
        .then((response) => {
        return onResourceResponseSuccess(lds, config, resourceParams, request, response);
    }, (response) => {
        return onResourceResponseError(lds, config, resourceParams, response);
    });
}
function resolveUnfulfilledSnapshot(lds, config, snapshot) {
    const resourceParams = createResourceParams(config);
    const request = createResourceRequest(resourceParams);
    return lds.resolveUnfulfilledSnapshot(request, snapshot)
        .then((response) => {
        return onResourceResponseSuccess(lds, config, resourceParams, request, response);
    }, (response) => {
        return onResourceResponseError(lds, config, resourceParams, response);
    });
}
const getCommunityNavigationMenuAdapterFactory = (lds) => function getCommunityNavigationMenu(untrustedConfig) {
    const config = validateAdapterConfig(untrustedConfig, getCommunityNavigationMenu_ConfigPropertyNames);
    // Invalid or incomplete config
    if (config === null) {
        return null;
    }
    const cacheSnapshot = buildInMemorySnapshot(lds, config);
    // Cache Hit
    if (lds.snapshotDataAvailable(cacheSnapshot) === true) {
        return cacheSnapshot;
    }
    if (cacheSnapshot.state === SNAPSHOT_STATE_UNFULFILLED) {
        return resolveUnfulfilledSnapshot(lds, config, cacheSnapshot);
    }
    return buildNetworkSnapshot(lds, config);
};

const getCommunityNavigationMenu = createWireAdapterConstructor(adapterName, getCommunityNavigationMenuAdapterFactory);

export { getCommunityNavigationMenu };
