import { createElement } from 'lwc';
import Element from 'lightning/input';

const defaultParams = {
    name: 'input',
    label: 'input',
};

const createInput = (params = {}) => {
    const element = createElement('lightning-input', { is: Element });
    Object.assign(element, defaultParams, params);
    document.body.appendChild(element);
    return element;
};

describe('lightning-input type=text', () => {
    const type = 'text';

    describe('selectionStart and selectionEnd', () => {
        it('should be valid when set from false to true', () => {
            const element = createInput({
                type,
                value: 'default string of joy',
                required: true,
            });

            element.focus();
            element.selectionStart = 3;
            element.selectionEnd = 7;

            const inputElement = element.shadowRoot.querySelector('input');

            return Promise.resolve().then(() => {
                expect(inputElement.selectionStart).toBe(3);
                // expect(element._inputElement.selectionStart).toBe(3);
                expect(inputElement.selectionEnd).toBe(7);
            });
        });
    });
});

describe('lightning-input type=number', () => {
    const type = 'number';

    describe('selectionStart and selectionEnd', () => {
        it('should be valid when set from false to true', () => {
            const element = createInput({
                type,
                value: 12345678.9,
                required: true,
            });

            element.focus();
            element.selectionStart = 3;
            element.selectionEnd = 7;

            const inputElement = element.shadowRoot.querySelector('input');

            return Promise.resolve().then(() => {
                expect(inputElement.selectionStart).toBe(3);
                // expect(element._inputElement.selectionStart).toBe(3);
                expect(inputElement.selectionEnd).toBe(7);
            });
        });
    });
});
